@@ -43,6 +43,7 @@
 #' @param disp.sd           a scalar or a vector whose dimension is equal to the number of data sets (including the current
 #'                          data) giving the scale parameters for the half-normal priors on the dispersion parameters. If a
 #'                          scalar is provided, same as for `meta.mean.mean`. Defaults to a vector of 10s.
+#' @param get.loglik        whether to generate log-likelihood matrix. Defaults to FALSE.
 #' @param iter_warmup       number of warmup iterations to run per chain. Defaults to 1000. See the argument `iter_warmup` in
 #'                          `sample()` method in cmdstanr package.
 #' @param iter_sampling     number of post-warmup iterations to run per chain. Defaults to 1000. See the argument `iter_sampling`
@@ -52,8 +53,13 @@
 #' @param ...               arguments passed to `sample()` method in cmdstanr package (e.g., `seed`, `refresh`, `init`).
 #'
 #' @return
-#'  The function returns an object of class `draws_df` giving posterior samples, with an attribute called 'data' which includes
-#'  the list of variables specified in the data block of the Stan program.
+#'  The function returns an object of class `draws_df` containing posterior samples. The object has two attributes:
+#'
+#'  \describe{
+#'    \item{data}{a list of variables specified in the data block of the Stan program}
+#'
+#'    \item{model}{a character string indicating the model name}
+#'  }
 #'
 #' @examples
 #' if (instantiate::stan_cmdstan_exists()) {
@@ -81,6 +87,7 @@ glm.bhm = function(
     meta.sd.sd        = NULL,
     disp.mean         = NULL,
     disp.sd           = NULL,
+    get.loglik        = FALSE,
     iter_warmup       = 1000,
     iter_sampling     = 1000,
     chains            = 4,
@@ -97,7 +104,8 @@ glm.bhm = function(
     meta.sd.mean   = meta.sd.mean,
     meta.sd.sd     = meta.sd.sd,
     disp.mean      = disp.mean,
-    disp.sd        = disp.sd
+    disp.sd        = disp.sd,
+    get.loglik     = get.loglik
   )
 
   glm_bhm    = instantiate::stan_package_model(
@@ -132,5 +140,7 @@ glm.bhm = function(
   d = rename.params(fit = fit, oldnames = oldnames, newnames = newnames)
   ## add data used for the variables specified in the data block of the Stan program as an attribute
   attr(x = d, which = 'data') = standat
+  ## add model name as an attribute
+  attr(x = d, which = 'model') = "glm_bhm"
   return(d)
 }
