@@ -47,6 +47,7 @@
 #'                          Defaults to 0.
 #' @param slab.sd           a scalar giving the scale parameter for the half-normal prior (slab component) on \eqn{\tau}.
 #'                          Defaults to 5.
+#' @param get.loglik        whether to generate log-likelihood matrix. Defaults to FALSE.
 #' @param iter_warmup       number of warmup iterations to run per chain. Defaults to 1000. See the argument `iter_warmup` in
 #'                          `sample()` method in cmdstanr package.
 #' @param iter_sampling     number of post-warmup iterations to run per chain. Defaults to 1000. See the argument `iter_sampling`
@@ -56,8 +57,13 @@
 #' @param ...               arguments passed to `sample()` method in cmdstanr package (e.g., `seed`, `refresh`, `init`).
 #'
 #' @return
-#'  The function returns an object of class `draws_df` giving posterior samples, with an attribute called 'data' which includes
-#'  the list of variables specified in the data block of the Stan program.
+#'  The function returns an object of class `draws_df` containing posterior samples. The object has two attributes:
+#'
+#'  \describe{
+#'    \item{data}{a list of variables specified in the data block of the Stan program}
+#'
+#'    \item{model}{a character string indicating the model name}
+#'  }
 #'
 #' @references
 #'  Hobbs, B. P., Carlin, B. P., Mandrekar, S. J., and Sargent, D. J. (2011). Hierarchical commensurate and power prior models for adaptive incorporation of historical information in clinical trials. Biometrics, 67(3), 1047–1056.
@@ -91,6 +97,7 @@ glm.commensurate = function(
     spike.sd          = 0.1,
     slab.mean         = 0,
     slab.sd           = 5,
+    get.loglik        = FALSE,
     iter_warmup       = 1000,
     iter_sampling     = 1000,
     chains            = 4,
@@ -115,7 +122,8 @@ glm.commensurate = function(
     spike.mean     = spike.mean,
     spike.sd       = spike.sd,
     slab.mean      = slab.mean,
-    slab.sd        = slab.sd
+    slab.sd        = slab.sd,
+    get.loglik     = get.loglik
   )
 
   glm_commensurate = instantiate::stan_package_model(
@@ -141,5 +149,7 @@ glm.commensurate = function(
   d = rename.params(fit = fit, oldnames = oldnames, newnames = newnames)
   ## add data used for the variables specified in the data block of the Stan program as an attribute
   attr(x = d, which = 'data') = standat
+  ## add model name as an attribute
+  attr(x = d, which = 'model') = "glm_commensurate"
   return(d)
 }
